package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0D```````````,`/@`!`````2````````!``````````%"A````
M`````````$``.``)`$``&P`:``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````=`````````!T``````````0`````````!````
M!0```````````````````````````````````-":````````T)H`````````
M`"````````$````&````8)L```````!@FR```````&";(```````P`0`````
M```("0``````````(````````@````8```!PFP```````'";(```````<)L@
M``````!``@```````$`"````````"``````````$````!````%@"````````
M6`(```````!8`@```````$0`````````1``````````$`````````%#E=&0$
M````.)0````````XE````````#B4````````Y`````````#D``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````&";````````8)L@``````!@FR``
M`````*`$````````H`0````````!`````````"]L:6(O;&0M:V9R965B<V0M
M>#@V+38T+G-O+C$`````!````!`````!````1TY5``,````(`````P``````
M```$````%`````,```!'3E4`CAB^E"&NK_X3X8Q)1[N\Q?IL.Q8`````$0``
M`$D````$````"````"`0$``%0`2$*`(``("&`(""*0``"2`$"8B@&44Z!`((
M`````$D```!-````40```%(```!8````60```%H```!<````70````````!?
M````8`````````!B``````````````!NQ=\?ZM/O#L[>1RUK?YI\+L6;MB#_
MY`ZXC?$.U634?-EQ6!SB1\8!K$OCP+KCDGS"Y3\L^J%L8+,!BV]K"4/69Z_,
M9D)%U>R)!W#3#13BGMK-XYXS8MOM#3J7"WZIG)O19<YMH^#[20``````````
M```````````````````````````5`P``$@````````````````````````"=
M`@``$@````````````````````````!9`P``$@``````````````````````
M`````@``$@`````````````````````````1````(```````````````````
M```````'`@``$@````````````````````````!Z`@``$@``````````````
M``````````!0`@``$@````````````````````````"(`@``$@``````````
M``````````````"T````$@````````````````````````"(`0``$@``````
M``````````````````!+`P``$@````````````````````````"$````$@``
M```````````````````````1`0``$@````````````````````````"6`@``
M$@````````````````````````!L`P``(0````````````````````````!B
M`@``$@`````````````````````````&`0``$0``````````````````````
M``!L`0``$@````````````````````````#H````$0``````````````````
M```````<`P``$@`````````````````````````Z`0``$@``````````````
M``````````#"````$@````````````````````````"V`0``$@``````````
M``````````````!(`@``$@`````````````````````````Q`@``$@``````
M``````````````````"C`0``$@````````````````````````!M`P``$0``
M``````````````````````#F`0``$@````````````````````````#G`@``
M$@````````````````````````#4`@``$@````````````````````````!(
M`0``$@`````````````````````````(`P``$@``````````````````````
M``!9`@``$@````````````````````````#Z`0``$@``````````````````
M```````M````(`````````````````````````#?`@``$@``````````````
M``````````"_`@``$@````````````````````````!D````$@``````````
M``````````````"D`@``$@````````````````````````!2`P``$@``````
M``````````````````!K`P``$0````````````````````````"V`P``$@``
M``````````````````````"3````$@````````````````````````"?````
M$@`````````````````````````@`@``$@````````````````````````!A
M`0``$@`````````````````````````G`0``$@``````````````````````
M``#X`@``$@````````````````````````!6````$@``````````````````
M``````!#`P``$@`````````````````````````6`0``$@``````````````
M```````````;`0``$@````````````````````````#&`@``$@``````````
M``````````````"8`0``$@````````````````````````#U````$@``````
M``````````````````"K`@``$@````````````````````````!Z`0``$@``
M``````````````````````!S````$@````````````````````````!S`@``
M$@````````````````````````"``@``$@````````````````````````#9
M````$@````````````````````````!8`0``$@``````````````````````
M``#Q`@``$0````````````````````````"/`@``$@``````````````````
M``````#_`@``$@`````````````````````````8`@``$@``````````````
M``````````"Q`@``$@`````````````````````````\````(```````````
M``````````````"O`0``$@````````````````````````!#`@``$@``````
M```````````````````U`P``$@````````````````````````"_`P``$@`.
M`-!3````````=P````````"-`P``$@`/`.14``````````````````#K`P``
M$@`.`!!%````````\`H```````!F`P``$@`.`.`=````````(0(```````"3
M`P``$@`.`&`^`````````P````````!/!```$@`.`'`^`````````@(`````
M``!)!```$@`+`.`9``````````````````!\!```$@`.``!0````````PP,`
M```````[!```$``8`""@(`````````````````#2`P``$@`.`(!`````````
M*0`````````%!```$0`0`/!4````````!`````````#4````$``8`&BD(```
M``````````````!'!```$@`.`-`]````````,P````````!<!```$@`.`#!$
M````````W@````````!N!```$@`.`(!#````````=`````````#X`P``$``7
M``"@(`````````````````#?`P``$@`.`+!`````````U`````````#+`P``
M$``7`""@(``````````````````D!```$0`7`!B@(```````"`````````"#
M`P``$@`.`.!4`````````@`````````4!```$@`.`'!4````````90``````
M``#^`P``$@`.``$@``````````````````#Z`P``(``7``"@(```````````
M``````"D`P``$@`.``!$````````)P`````````F`P``(@``````````````
M```````````N!```$@`.`)!!````````YP$`````````;&EB<&5R;"YS;RXU
M+C(X`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%]E;F0`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8F1L+G-O+C(`;&EB
M;2YS;RXQ`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L
M;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C
M+G-O+C`N,0!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D
M=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER
M`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V
M-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?
M;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?
M<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]?;&EB8U]C<W5?9FEN
M:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`%]E9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`
M<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!?7V)S<U]S=&%R
M=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C,`1TQ)
M0D-?,BXQ-`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`````
M`@`"``(``P````,``@`"``(```````(```````(``@`$``````````(`````
M`````@`%`````@`#``(``@````8``@`#`````@`'`````@`"``(``@``````
M`P```````@````(``@````8```````(```````(``@```````@`"``(``P`&
M`````@`"``8``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``@`!``$``0#6`0``$````"`````3:6D-```#`)($````
M`````0`%`"4"```0`````````)21E@8```<`G`0``!````!T&6D)```&`*<$
M```0````<AEI"0``!0"S!```$````!1I:0T```0`OP0``!`````3:6D-```"
M`)($````````8)L@```````(`````````/`@````````:)L@```````(````
M`````+`@````````"*`@```````(``````````B@(```````&*`@```````(
M``````````!8````````J)\@```````&````!0``````````````L)\@````
M```&````"P``````````````N)\@```````&````$@``````````````P)\@
M```````&````%```````````````R)\@```````&````'```````````````
MT)\@```````&````)```````````````V)\@```````&````80``````````
M````X)\@```````&````,```````````````Z)\@```````&````.P``````
M````````\)\@```````&````0```````````````^)\@```````&````10``
M````````````R)T@```````'`````0``````````````T)T@```````'````
M`@``````````````V)T@```````'`````P``````````````X)T@```````'
M````!```````````````Z)T@```````'````!@``````````````\)T@````
M```'````!P``````````````^)T@```````'````"````````````````)X@
M```````'````"0``````````````")X@```````'````"@``````````````
M$)X@```````'````#```````````````&)X@```````'````#0``````````
M````()X@```````'````#@``````````````*)X@```````'````#P``````
M````````,)X@```````'````$0``````````````.)X@```````'````$P``
M````````````0)X@```````'````%0``````````````2)X@```````'````
M%@``````````````4)X@```````'````%P``````````````6)X@```````'
M````&```````````````8)X@```````'````&0``````````````:)X@````
M```'````&@``````````````<)X@```````'````&P``````````````>)X@
M```````'````'0``````````````@)X@```````'````'@``````````````
MB)X@```````'````'P``````````````D)X@```````'````(```````````
M````F)X@```````'````(0``````````````H)X@```````'````(@``````
M````````J)X@```````'````(P``````````````L)X@```````'````)0``
M````````````N)X@```````'````)@``````````````P)X@```````'````
M)P``````````````R)X@```````'````*```````````````T)X@```````'
M````*0``````````````V)X@```````'````*P``````````````X)X@````
M```'````+```````````````Z)X@```````'````+0``````````````\)X@
M```````'````+@``````````````^)X@```````'````+P``````````````
M`)\@```````'````,0``````````````")\@```````'````,@``````````
M````$)\@```````'````,P``````````````&)\@```````'````-```````
M````````()\@```````'````-0``````````````*)\@```````'````-@``
M````````````,)\@```````'````-P``````````````.)\@```````'````
M.```````````````0)\@```````'````.0``````````````2)\@```````'
M````.@``````````````4)\@```````'````/```````````````6)\@````
M```'````/0``````````````8)\@```````'````/@``````````````:)\@
M```````'````/P``````````````<)\@```````'````00``````````````
M>)\@```````'````0@``````````````@)\@```````'````0P``````````
M````B)\@```````'````1```````````````D)\@```````'````1@``````
M````````F)\@```````'````1P``````````````H)\@```````'````2```
M````````````2(/L"$B+!>6%(`!(A<!T`O_02(/$",,```````````#_-;*#
M(`#_);2#(``/'T``_R6R@R``:`````#IX/____\EJH,@`&@!````Z=#_____
M):*#(`!H`@```.G`_____R6:@R``:`,```#IL/____\EDH,@`&@$````Z:#_
M____)8J#(`!H!0```.F0_____R6"@R``:`8```#I@/____\E>H,@`&@'````
MZ7#_____)7*#(`!H"````.E@_____R5J@R``:`D```#I4/____\E8H,@`&@*
M````Z4#_____)5J#(`!H"P```.DP_____R52@R``:`P```#I(/____\E2H,@
M`&@-````Z1#_____)4*#(`!H#@```.D`_____R4Z@R``:`\```#I\/[___\E
M,H,@`&@0````Z>#^____)2J#(`!H$0```.G0_O___R4B@R``:!(```#IP/[_
M__\E&H,@`&@3````Z;#^____)1*#(`!H%````.F@_O___R4*@R``:!4```#I
MD/[___\E`H,@`&@6````Z8#^____)?J"(`!H%P```.EP_O___R7R@B``:!@`
M``#I8/[___\EZH(@`&@9````Z5#^____)>*"(`!H&@```.E`_O___R7:@B``
M:!L```#I,/[___\ETH(@`&@<````Z2#^____)<J"(`!H'0```.D0_O___R7"
M@B``:!X```#I`/[___\ENH(@`&@?````Z?#]____);*"(`!H(````.G@_?__
M_R6J@B``:"$```#IT/W___\EHH(@`&@B````Z<#]____)9J"(`!H(P```.FP
M_?___R62@B``:"0```#IH/W___\EBH(@`&@E````Z9#]____)8*"(`!H)@``
M`.F`_?___R5Z@B``:"<```#I</W___\E<H(@`&@H````Z6#]____)6J"(`!H
M*0```.E0_?___R5B@B``:"H```#I0/W___\E6H(@`&@K````Z3#]____)5*"
M(`!H+````.D@_?___R5*@B``:"T```#I$/W___\E0H(@`&@N````Z0#]____
M)3J"(`!H+P```.GP_/___R4R@B``:#````#IX/S___\E*H(@`&@Q````Z=#\
M____)2*"(`!H,@```.G`_/___R4:@B``:#,```#IL/S___\E$H(@`&@T````
MZ:#\____)0J"(`!H-0```.F0_/___R4"@B``:#8```#I@/S___\E^H$@`&@W
M````Z7#\____)?*!(`!H.````.E@_/___R7J@2``:#D```#I4/S___\EXH$@
M`&@Z````Z4#\____)=J!(`!H.P```.DP_/___R4"@B``9I```````````%53
M2(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````2(E$
M)"@QP.CH_?__2(LUP8$@`$B+/<*!(`!(B?+H(C8``$B+!8N!(`"`.``/A#0!
M``!(BQUS@2``BSOH)/W__XL[2(T=8C@``("(P@,```+H#_W__X"(P@,```&+
M1"0<C7@%2&/_2,'G`^CE_/__3(M,)!#'!<:%(``$````2(D%MX4@`$F+$4B)
M6`A(C1T;.```2(E8&$B)$$B+%6N!(`!(B5`0BU0D'(/Z`7XNC4K^O@$```!(
M@\$"9BX/'X0``````$V+!/&-?@1(@\8!2&/_3(E$^/A(.?%UZ(U*!$4QP(/"
M`TB+/6B%(`!(8\E(C34.'P``2,=$R/@`````2(G!Z,W]__^)PX7`#X2(````
M2(L]/(4@`$B-;"0DZ,+[__\QP$B)[DB-/4TV``#HX1<``$B%P'1T2(L]%84@
M`.AP^___Z#O]__^)V$B+7"0H9$@S'"4H````#X6'````2(/$.%M=P^BY^___
M2(D%XH0@`$B%P'1T2(G'Z"7[__](BQTF@"``BSOHU_O__\:`60D```#IH/[_
M_TB+/;2$(`#HG_W__XG#Z67___](BSV9A"``2(7_=`KH!S0``.EV____2(T]
M9S4``$B)[NA#%P``2(G'2(D%<80@`$B%P`^$5/___^O2Z.GZ__^_`0```.BO
M_?__,>U)B?%(BS=(C5<(2(/D\%!43(T%QC0``$B-#4\T``!(C3VX_?__Z`/Z
M___T2(T%,X0@`&8N#Q^$``````"02(T]V7\@`$B-!=)_(`!(.?AT%4B+!4Y_
M(`!(A<!T"?_@#Q^``````,,/'X``````2(T]J7\@`$B--:)_(`!(*?Y(P?X#
M2(GP2,'H/T@!QDC1_G042(L%77\@`$B%P'0(_^!F#Q]$``###Q^``````(`]
M:7\@``!U+U5(@ST6?R```$B)Y70,2(L].G\@`.C]_/__Z&C____&!4%_(``!
M7<,/'X``````PP\?@`````#I>____V8N#Q^$``````"005=,C4<X3(U7>$%6
M055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``,<!(B>))B=%F#Q]$``!!
MBP!)BS!)@\`(28/!$`_(B<!(B?%)B4'P2(GP2,'I($C!Z"A(P>XX)0#_``!(
M"?!(B<Y(P>$(2,'F&('A``#_`(GV2`GP2`G(28E!^$TYPG6N2(VR``(```\?
M@`````!(BT)H2#-"0$B#P@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y
M\G753(L72(M?$$B+=R!(BV\83(G03(G23(M/"$C!ZAM(P>`%2`G0`P0DC90P
MF7F"6DB)V$B+="0(2#'H3"'(2(VT-9EY@EI(,>A$C2P"3(G*3(G(2,'H`DC!
MXAY-B>A("<)(B=A)P>@;B=%(,<A,(=!(,=A(`?!,B>Y(P>8%3`G&1(TD!DR)
MUDR)T$C!YAY(P>@"38GC2`GP2(MT)!!)P>L;2#'"08G`3"'J2(VT,YEY@EI(
M,<I(`?),B>9(P>8%3`G>1(T<%DR)[DG![0)(BU0D&$C!YAY,">Y(C901F7F"
M6DR)V4@Q\$&)]DPAX$PQP$C!Z1M(`=!,B=I(P>(%2`G*3(GA2<'L`DC!X1Y$
MC2P"2(GP2(M4)"!,">%,B>Y(,<A)C900F7F"6DC![AM!B<Q,(=A,,?!(`=!,
MB>I(P>(%2`GR1(T$`DR)VDG!ZP)(BT0D*$C!XAY,B<9,"=I)C80&F7F"6DC!
M[AM(,=%!B=-,(>E,,>%(`<%,B<!(P>`%2`GP1(TT"$R)Z$G![0)(BTPD,$C!
MX!Y,B?9,">A)C8P,F7F"6D@QPD&)Q4PAPDPQVD@!RDR)\4C!X05(P>X;2`GQ
M3(G&2<'H`DC!YAY$C2012(M4)#A,"<9,B>%(,?!)C903F7F"6DC!Z1M!B?!,
M(?!,,>A(`=!,B>)(P>(%2`G*3(GQ2<'N`DC!X1Y$C1P"2(GP2(M4)$!,"?%,
MB=Y(,<A)C905F7F"6DC![AM!B<Y,(>!,,<!(`=!,B=I(P>(%2`GR1(TL`DR)
MXDG![`)(BT0D2$C!XAY,B>Y,">))C80`F7F"6DC![AM(,=%!B=1,(=E,,?%(
M`<%,B>A(P>`%2`GP1(T$"$R)V$G!ZP)(BTPD4$C!X!Y,B<9,"=A)C8P.F7F"
M6DC![AM(,<)!B<-,(>I,,>)(`<I,B<%(P>$%2`GQ3(GN2<'M`DC!YAY$C301
M2(M4)%A,">Y,B?%(,?!)C904F7F"6DC!Z1M!B?5,(<!,,=A(`=!,B?)(P>(%
M2`G*3(G!2<'H`DC!X1Y$C20"2(GP2(M4)&!,"<%,B>9(,<A)C903F7F"6DC!
M[AM!B<A,(?!,,>A(`=!,B>)(P>(%2`GR1(T<`DR)\DB+1"1H2,'B'DG![@),
MB=Y,"?))C80%F7F"6DC![AM(,=%!B=9,(>%,,<%(`<%,B=A(P>`%2`GP1(TL
M"$R)X$G![`)(BTPD<$C!X!Y,B>Y,">!)C8P(F7F"6DC![AM(,<)!B<1,(=I,
M,?)(`<I,B>E(P>$%2`GQ3(G>2<'K`DC!YAY$C0012(M4)'A,"=Y,B<%(,?!)
MC906F7F"6DC!Z1M!B?-,(>A,,>!(`=!,B<)(P>(%2`G*3(GI2<'M`DC!X1Y$
MC30"2(GP2(N4)(````!,">E,B?9(,<A)C904F7F"6DC![AM!B<U,(<!,,=A(
M`=!,B?)(P>(%2`GR1(TD`DR)PDG!Z`)(BX0DB````$C!XAY,B>9,"<))C80#
MF7F"6DC![AM(,=%!B=!,(?%,,>E(`<%,B>!(P>`%2`GP2(NT))````!$C1P(
M3(GP2<'N`DC!X!Y)C;0UF7F"6DV)W4P)\$G![1M(,<*)P4PAXDPQPD@!\DR)
MWDC!Y@5,">Z)]D@!\DR)YDG![`)(P>8>08G53`GF3(ND))@```!(,?!,(=A/
MC80@F7F"6DV)[$@QR$G![!M,`<!-B>A)P>`%30G@18G`3`'`38G82<'K`DG!
MX!Y!B<1-"=A)B?.)]D@#M"2H````33'#1#':3(N<)*````!*C8P9H>O9;DV)
MXT@!T4R)XDG!ZQM(P>(%3`G:B=)(`=%,B>I)P>T"2,'B'D&)RTP)ZDV)Q46)
MP$P#A"2P````23'51#'H38G=2(VT!J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'P
M3(GF2<'L`DC!YAY!B<5,">9)B=2)TDDQ]$0QX4V)[$@#E"2X````38V$"*'K
MV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G92<'K`DC!X1Y%B<1,"=E)B?.)]D@#
MM"3`````23'+1#'838GC2(V4`J'KV6Y,B>!)P>L;2,'@!4P)V(G`2`'"3(GH
M2<'M`DC!X!Y!B=-,">A)B<V)R4@#C"3(````23'%13'H38G=3HV$!J'KV6Y,
MB=Y)P>T;2,'F!4P)[HGV3`'&38G@2<'L`DG!X!Y!B?5-">!)B<2)P$TQQ$0Q
MXDV)[$B-C!&AZ]EN3(GJ2,'B!4G![!M(`X0DT````$P)XHG22`'13(G:2<'K
M`DC!XAY!B<Q,"=I-B<-%B<!,`X0DV````$DQTT0QWDV)XTB-M#"AZ]EN3(G@
M2<'K&TC!X`5,"=B)P$@!\$R)[DG![0)(P>8>08G#3`GN28G5B=)(`Y0DX```
M`$DQ]40QZ4V)W4V-A`BAZ]EN3(G92<'M&TC!X05,">F)R4D!R$R)X4G![`)(
MP>$>18G%3`GA28GTB?9),<Q$,>!-B>Q(C90"H>O9;DR)Z$G![!M(P>`%3`G@
MB<!(`<),B=A)P>L"2`.T).@```!(P>`>08G43`G828G+B<E(`XPD\````$DQ
MPT4QV$V)XTZ-A`:AZ]EN3(GF2<'K&TC!Y@5,"=Z)]DP!QDV)Z$G![0))P>`>
M08GS30GH28G%B<!(`X0D^````$TQQ40QZDV)W4B-C!&AZ]EN3(G:2<'M&TC!
MX@5,">J)TD@!T4R)XDG![`)(P>(>08G-3`GB38G$18G`23'41#'F38GL2(VT
M,*'KV6Y,B>A)P>P;2,'@!4P)X(G`2`'P3(G>2,'F'DG!ZP)!B<1,`X0D``$`
M`$P)WDF)TXG22`.4)`@!``!),?-$,=E-B>--C80(H>O9;DR)X4G!ZQM(P>$%
M3`G9B<E)`<A,B>E)P>T"2,'A'D6)PTP)Z4F)]8GV2`.T)!`!``!),<U$,>A-
MB=U(C90"H>O9;DR)V$G![1M(P>`%3`GHB<!(`<),B>!)P>P"2,'@'D&)U4P)
MX$F)S(G)23'$13'@38GL3HV$!J'KV6Y,B>Y)P>P;2,'F!4P)YHGV3`'&38G8
M2<'K`DG!X!Y!B?1-"=A)B<-(`XPD&`$``(G`33'#2`.$)"`!``!$,=I-B>-(
MC8P1H>O9;DR)XDG!ZQM(P>(%3`G:B=)(`=%,B>I)P>T"2,'B'D&)RTP)ZDV)
MQ46)P$P#A"0H`0``23'51#'N38G=2(VT,*'KV6Y,B=A)P>T;2,'@!4P)Z(G`
M2`'P3(GF2<'L`DC!YAY!B<5,">9)B=2)TD@#E"0P`0``23'T1#'A38GL38V$
M"*'KV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G92<'K`DC!X1Y%B<1,"=E)B?.)
M]DDQRT0QV$V)XT@#M"0X`0``2(V4`J'KV6Y,B>!)P>L;2,'@!4P)V$2-'!!,
MB>A)P>T"2,'@'DP)Z$F)S8G)23'%B<)%,>A-B=U.C80&H>O9;DR)WDG![1M(
MP>8%3`GN3(NL)$`!``!&C30&38G@2<'L`DG!X!Y-">!,"<!$B<9)B<1(B=!(
M(?!-(=Q)"<2XW+P;CTD!Q4P!Z4V)]4D!S$R)\4G![1M(P>$%3`GI28GU00',
M3(G92<'K`DC!X1Y,"=E!B<M)"<A-(?!-(=U-">A,BZPD2`$``$D!Q4P!ZDV)
MY4D!T$R)XDG![1M(P>(%3`GJ1HTL`DR)\DG![@)(P>(>3`GR38G>08G02`G1
M32'&3"'A3`GQ3(NT)%`!``!)`<9,`?9-B>Y(`?%,B>Y)P>X;2,'F!4P)]D2-
M-`Y,B>9)P>P"2,'F'DP)YDV)Q(GQ2`GR22',3"'J3`GB3(ND)%@!``!)`<1-
M`>--B?1,`=I-B?-)P>,%2<'L&TT)XT6-)!--B>M)P>T"2<'C'DT)ZTF)S42)
MVDP)WDDAU4PA]DP)[DR+K"1@`0``20'%30'H38GE3`'&38G@2<'M&TG!X`5-
M">A%C2PP38GP2<'N`DG!X!Y-"?!)B=9$B<9-"<-)(?9-(>--"?-,B[0D:`$`
M`$D!QDP!\4V)[DD!RTR)Z4G![AM(P>$%3`GQ1HTT&4R)X4G![`)(P>$>3`GA
M28GT08G+20G(32'H32'<30G@3(ND)'`!``!)`<1,`>)-B?1)`=!,B?))P>P;
M2,'B!4P)XD:-)`),B>I)P>T"2,'B'DP)ZDV)W4&)T$@)T4TAQ4PA\4P)Z4R+
MK"1X`0``20'%3`'N38GE2`'Q3(GF2<'M&TC!Y@5,">Y$C2P.3(GV2<'N`DC!
MYAY,"?9-B<:)\4@)\DDASDPAXDP)\DR+M"2``0``20'&30'S38GN3`':38GK
M2<'C!4G![AM-"?-%C30338GC2<'L`DG!XQY-">-)B<Q$B=I,"=Y)(=1,(>Y,
M">9,BZ0DB`$``$D!Q$T!X$V)]$P!QDV)\$G![!M)P>`%30G@18TD,$V)Z$G!
M[0))P>`>30GH28G51(G&30G#22'U32'S30GK3(NL))`!``!)`<5,`>E-B>5)
M`<M,B>%)P>T;2,'A!4P)Z4:-+!E,B?%)P>X"2,'A'DP)\4F)]DD)R$&)RTTA
MWDTAX$T)\$R+M"28`0``20'&3`'R38GN20'03(GJ2<'N&TC!X@5,"?)&C30"
M3(GB2<'L`DC!XAY,">)-B=Q!B=!("=%-(<1,(>E,">%,BZ0DH`$``$D!Q$P!
MYDV)]$@!\4R)]DG![!M(P>8%3`GF1(TD#DR)[DG![0)(P>8>3`GN38G%B?%(
M"?))(<U,(?),">I,BZPDJ`$``$D!Q4T!ZTV)Y4P!VDV)XTG![1M)P>,%30GK
M18TL$TV)\TG![@))P>,>30GS28G.1(G:3`G>22'63"'F3`GV3(NT)+`!``!)
M`<9-`?!-B>Y,`<9-B>A)P>X;2<'@!4T)\$6--#!-B>!)P>P"2<'@'DT)X$F)
MU$2)QDT)PTDA]$TAZTT)XTR+I"2X`0``20'$3`'A38GT20'+3(GQ2<'L&TC!
MX05,">%&C2093(GI2<'M`DC!X1Y,">E)B?5!B<M)"<A-(?!-(=U-">A,BZPD
MP`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ1HTL`DR)\DG![@)-B=A(
MP>(>3`GR08G62`G132'P3"'A3`G!3(N$),@!``!)`<!,`<9-B>A(`?%,B>Y)
MP>@;2,'F!4P)QD2-!`Y,B>9)P>P"3(GQ2,'F'DP)YD&)]$@)\DPAX4PAZD@)
MRDB+C"30`0``2`'!20'+3(G!2`.$)-@!``!,`=I-B<-(P>$%3`'P2<'K&TP)
MV8G)2`'*3(GI2<'M`DC!X1Y!B=-,">E-B>5!B<]("<Y-(?U,(<9,">Y-B=U(
M`?!,B=Y)P>T;2,'F!4P)[HGV2`'P3(G&2<'H`DC!YAY!B<5)"?"^UL%BRDPQ
MP3'*2(N,).`!``!(`?%)`<Q,B>E,`>)-B>Q(P>$%2<'L&TP)X8G)2`'*3(G9
M2,'A'DG!ZP)!B=1)"<M,B<%-B>9%B<!,,=E)P>X;,<A(BXPDZ`$``$@!\4D!
MSTJ-##A,B>!(P>`%3`GPB<!,C30!3(GH2<'M`DR)V4C!X!Y%B?=%B=M)"<5(
MBX0D\`$``$PQZ4@!\#'*3(GY3`'`2,'I&T@!PDR)^$C!X`5("<A(BXPD^`$`
M`(G`2`'"3(G@2`'Q2<'L`DC!X!Y,`=E-B>M!B=!,">!-B<1%B>U),<-)P>P;
M13'>3HT<,4R)P4C!X05,">&)R4D!RTR)^4G![P)(P>$>18G<20G/2(N,)``"
M``!(`?%,`>E)B<6)P$TQ_40QZDR-+!%,B>),B>%(P>D;2,'B!4@)RDR)P4G!
MZ`*)TDC!X1Y)`=5(BY0D"`(``$P)P4V)^$DQR$6)[D6)_T@!\D4QPT@!T$R)
M\DZ-!!A,B?!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B>!)P>P"2,'@'D6)PTD)
MQ$B+A"00`@``3#'B2`'P03'53(G:3`'X20'%3(G82,'@!4C!ZAM("=!,B?))
MP>X"B<!(P>(>20'%2(N$)!@"``!,"?)%B>](`?!(`<A,B>%%B>1(,=%!,<A,
MB?E)`<!,B?A(P>D;2,'@!4@)R(G`20'`3(G82<'K`DC!X!Y%B<9)"<-(BX0D
M(`(``$R)\4C!Z1M(`?!,`>!)B=2)TDTQW$4QY4Z-)"A,B?!(P>`%2`G(2(N,
M)"@"``")P$D!Q$R)^$@!\4G![P)(P>`>2`'*3(G918GE3`GX18G;2#'!03'(
M3(GI20'03(GJ2,'I&TC!X@5("<J)TDD!T$R)\DG![@)(P>(>18G'20G62(N4
M)#`"``!,B?E(P>D;2`'R3`':28G#B<!-,?-%,=Q.C1PB3(GZ2,'B!4@)RDR)
MZ4G![0*)TDC!X1Y)`=-(BY0D.`(``$P)Z46)W$@!\D@!T$R)\D6)]D@QRD$Q
MT$R)XDD!P$R)X$C!ZAM(P>`%2`G02(G*B<F)P$D!P$R)^$G![P)(P>`>18G%
M20G'2(N$)$`"``!(`?!,,?I,`?!!,=-,B>I)`<-,B>A(P>H;2,'@!4@)T$R)
MXDG![`*)P$C!XAY)`<-(BX0D2`(``$P)XD6)WDF)U$@!\$@!R$R)^46)_T@Q
MT8G203'(2HT,`$R)\$V)\$G!Z!M(P>`%3`G`B<!(`<%,B>A)P>T"2,'@'D&)
MR$D)Q4B+A"10`@``33'L2`'P13'C38G$3`'X2<'L&TD!PTR)P$C!X`5,">")
MP$D!PTR)\$C!X!Y)P>X"18G<3`GP3(NT)%@"``!)`?9)`=9,B>I%B>U(,<(Q
MT4F-%`Y,B>%-B>9)P>X;2,'A!4P)\8G)2`'*3(G!2<'H`DC!X1Y!B=9)"<A(
MBXPD8`(``$@!\4P!Z4F)Q8G`33'%13'K38GU20'+3(GQ2<'M&TC!X05,">F)
MR4D!RTR)X4G![`)(P>$>18G=20G,2(N,)&@"``!(`?%(`<A,B<%%B<!,,>$Q
MRDB-#!!,B>A,B>I(P>H;2,'@!4@)T$R)\DG![@)(P>(>B<!)"=9(BY0D<`(`
M`$@!P8G(2`'R3`'"38G@33'P13'#28G`3`':28G#2<'@!4G!ZQM-"=A)B<-(
MP>@"2<'C'D$!T$R)ZDG![0))"<-(BX0D>`(``$C!XAY)"=5$B>)!`=M(`?!$
M`>U,B5\02`'"3(GP2(EO&$PQZ#'!2(T$"DR)PDR)P44!R$C!X@5(P>D;3(E'
M"$@)R@'000'"1`-W($R)%TR)=R!(BX0DB`(``&1(,P0E*````'422('$F`(`
M`%M=05Q!74%>05_#Z,KC__]F+@\?A```````05=!5D%505154TB#[`A(A?\/
MA+$```!(BP6*:"``3(LX387_#X2>````#[8'A,!T!#P]=5M%,>1)BQ](A=MT
M-DF)]4F)_DUCY$R)_0\?0`!,B>),B?9(B=_HPN/__X7`=0="@#PC/71'2(/%
M"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\28/$`4$/
MM@0DA,!T!#P]=>]!*?SKCP\?@`````!,*?U*C5PC`4C!_0-!B6T`Z[1F#Q]$
M```QV^NJ#Q]``%5(B?U32(/L&&1(BP0E*````$B)1"0(,<!(C5PD!&:0,<!(
MB=Y(B>_H`____TB%P'0^2(L%GV<@`$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)T
MSP\?@`````!(@\`(2(M0"$B)$$B%TG7PZ[9F#Q]$``!(BT0D"&1(,P0E*```
M`'4'2(/$&%M=P^ADXO__#Q]``$%7059!54%454B)]5-(B?M(@^PH9$B+!"4H
M````2(E$)!@QP#'`@#X]#Y3`2`'%2(GOZ&GA__](C70D%$B)WTF)Q#'`Z%?^
M__](A<`/A`X!``!(B<=)B<7H0^'__TPYX`^#V@```$AC3"043(LMUF8@`$C!
MX0,/M@.$P`^$KP$``#P]#X2G`0``2(G8#Q]``$B#P`$/MA"$TG0%@/H]=?!(
M*=A(F$D#30!*C7P@`DF)SNAJY/__28D&2(7`#X2"`0``28M%`$AC5"042(U+
M`4B+%-`/M@.(`CP]="*$P'4,ZQQF#Q]$```\/7022(/!`0^V0?](@\(!B`*$
MP'7JQ@(],<`/'T0```^V3`4`B$P"`4B#P`&$R77O,<!(BUPD&&1(,QPE*```
M``^%'P$``$B#Q"A;74%<05U!7D%?PV:0,<!F#Q]$```/ME0%`$&(5`4`2(/`
M`832=>[KO0\?0`!,BRWA92``38M]`$F#/P`/A,(```!,B?@QTNL'#Q]``$2)
M\DB#P`A$C7(!2(,X`'7OC7(#2&/V2,'F`XL%'VH@`(7`=6/'!1%J(``!````
M2(GWZ&GC__](A<`/A(0```!-8\Y,B?Y(B<=*C0S-`````$R)3"0(2(G*2(D,
M).@^XO__3(M,)`A(BPPD28E%`$F)P$O'1,@(`````$2)="04Z7'^__\/'P!,
MB?_HH.+__TF)P$F)10!(A<!T*$UCSDJ-#,T`````Z\D/'X``````,<#I;O[_
M_[X0````13'VZ5?___^X_____^G-_O__Z`W@__]F9BX/'X0``````&:0059!
M54%455-(@>R0````9$B+!"4H````2(F$)(@````QP$B%_W0(@#\`2(G]=3%(
MBX0DB````&1(,P0E*`````^%,0$``$B!Q)````!;74%<05U!7L-F+@\?A```
M````Z)O@__])B<1(A<!TPDF)Y4R)Y^BHW___2(G#2(7`#X2D````#[9#"(/X
M+@^$KP```$B)[TB#PPCHH][__TB)WTF)QNB8WO__08U\!@)(8__H"^+__TF)
MV4F)Z+X!````28G&2(G',<!(Q\+_____2(T-/AD``.@%XO__OP,```!,B>I,
MB?;HM=___TR)]X/X_W0/#[=$)!!F)0#P9CT`0'1NZ#GA__],B??HP>#__TR)
MY^@)W___2(G#2(7`#X5A____#Q]$``!,B>?HL-___TB)[^CHX/__Z?+^__\/
M'P`/ME,)A=(/A"3___\YT'00@^HNA=(/A!7____I,?___P^V4PKK[68N#Q^$
M``````#HB_[__^N0Z(3>__\/'T``4TB)_DB)^[\#````2('LD````&1(BP0E
M*````$B)A"2(````,<!(B>+H`M___X7`=38/MU0D$('B`/```('Z`$```'0(
M@?H`H```=1V^`@```$B)W^CFW?__A<`/E,`/ML#K!@\?0``QP$B+C"2(````
M9$@S#"4H````=0E(@<20````6\/H]=W__P\?1```05:Z_P,``$F)]D%5051)
MB?Q(C3WR%P``55-(@>P0!```9$B+!"4H````2(F$)`@$```QP$B)XTB)WNA!
MX/__A<!^=8U0_TB+#7MB(`!(8^J`/"P`1(LI=5>%TG1E2(GJOB\```!(B=_H
M(]W__TB%P'101(GOZ`;>__](B>E(B=I,B>9(B<?HQ=___TB+A"0(!```9$@S
M!"4H````=3Q(@<00!```6UU!7$%=05[#9I!(8^CKJ`\?`$B+!0EB(`!$BRA$
MB>_HMMW__TR)\DR)YDB)Q^A(W?__Z['H$=W__Y!(@^P(2(L%W6$@`(LXZ([=
M__](BQ7'82``2(/$"$B-#?08``!(C34.%P``2(G'Z6W>__]F9BX/'X0`````
M`&:04TB+':!A(`"+.^A1W?__2(G'Z*G___^+.^A"W?__3(T%7Q@``$4QR5M,
MB<%(C16]$0``2(TUVQ8``$B)Q^F>WO__9F8N#Q^$```````/'P`QP,-F9BX/
M'X0``````&:005=!5D%5051)B?152(G]2(T]MA8``%-(@>RX!```9$B+!"4H
M````2(F$)*@$```QP$B-="0,Z'7X__^^+P```$B)[TB)P^A5V___2(7`=$!(
MB>Y(C3U[%@``,<#HK_G__TB)Z$B+C"2H!```9$@S#"4H````#X6"`0``2('$
MN`0``%M=05Q!74%>05_##Q\`2(GOZ!C;__](C35#%@``3(GG08G%Z+;;__])
MB<=(A<!TGD&#Q0%!@#\`3(UT)!!,C:0DH`````^$R`````\?`$B%VW033(G^
M2(G?Z-#<__^%P`^$B0```$R)_^C`VO__B<)(F$&`?`?_+W47#Q]``(/J`4AC
MPD&`?`?_+T'&!`<`=.U$`>J!^O\#```/CR[___](@^P(2(T-K18``$V)^#'`
M54R-#:H5``"Z``0``$R)Y[X!````Z`3>__],B?),B>:_`P```.BTV___6EF%
MP'4/#[=$)"!F)0#P9CT`@'1?2(TU:A4``#'_Z.':__])B<=(A<`/A,7^__]!
M@#\`#X4[____2(7;=!ZY`@```$B)WDB-/2$5``#SI@^7P!P`A,!TO0\?0`!,
MC3T+%0``N@$```#I2O___P\?@`````"^`0```$R)Y^A3VO__A<!UD$R)YDB-
M/>H4``#H(/C__TR)Y^@(VO__Z6?^___H;MK__V9F+@\?A```````#Q\`#[87
M2(GXA-)T'F8/'T0``$B#QP&`^B\/MA=(#T3'A-)U[L,/'T0``,,/'X``````
M4TB%_P^$I@```(`_`$B)^P^$F@```.A5V?__2(U4`_](.=-R%.LG9@\?A```
M````2(/J`4@YTW0:@#HO=/+K!8`Z+W0H2(/J`4@YTW+R2#G3=1J`.B]T6$B-
M/444``!;Z5O9__\/'P"`.B]U"4B#Z@%(.=-R\D@IVDB-0@)(/0`$``!W2TB)
MWDB#P@&Y``0``$B-/?A>(`#H@]O__TB-!>Q>(`!;PV8N#Q^$``````"_`@``
M`.@VW/__2(7`=!&Z+@```&:)$%O##Q^``````#'`6\-F9BX/'X0``````)!3
M2(T]OA,``$B#[$#S#V\%'!4``/,/;PTD%0``9$B+!"4H````2(E$)#@QP`^W
M!1T5``!(C5PD#`\I1"009HE$)#`QP`\I3"0@Z!+V__\QP$B-/7@3``#H!/;_
M_S'`2(T]<A,``.CV]?__,<!(C3UM$P``Z.CU__\QP$B-/683``#HVO7__S'`
M2(T]:!,``.C,]?__,<!(C3T/$P``Z+[U__\QP$B-/5@3``#HL/7__S'`2(T]
M5!,``.BB]?__,<!(C3U0$P``Z)3U__\QP$B-/>`2``#HAO7__S'`2(G>2(T]
M.Q,``.BE]/__2(7`=!%(B<9(C3T3$P``,<#H[_7__S'`2(G>2(T])1,``.A^
M]/__2(7`=!%(B<9(C3TC$P``,<#HR/7__S'`2(G>2(T]&Q,``.A7]/__2(7`
M=$)(B<9(C3UD$@``,<#HH?7__S'`2(TU(Q,``$B-/8@2``#HC/7__TB+1"0X
M9$@S!"4H````=6Y(@\1`6\-F#Q]$```QP$B)WDB-/=,2``#H__/__TB%P'0:
M2(G&2(T]8Q(``#'`Z$GU___KI@\?@`````!(C70D(;D*````2(T]KQ(``/.F
M#Y?`'`"$P'6#2(UT)"M(C3TK$@``Z!/U___I;?___^AIU___9@\?A```````
M2(/L&&1(BP0E*````$B)1"0(,<"+!79<(`"#^/]T&4B+?"0(9$@S/"4H````
M=4!(@\08PP\?0`!(C70D!$B-/<\1```QP.A5\___2(G",<!(A=)T$@^V$H#Z
M,`^5P3'`A-(/E<`AR(D%(UP@`.NPZ.S6__]F9BX/'X0``````)!(@^P(Z'?8
M__^)Q^@@V/__2(7`=`M(BP!(@\0(PP\?`#'`2(/$",-F#Q^$``````!!5%5(
MB?U(C3W0$0``4TB#[!!D2(L$)2@```!(B40D"#'`2(UT)`3HQ/+__TB)[DB%
MP'0(@#@`2(G#=2Q(C3V:$0``,<#H!O3__TB+1"0(9$@S!"4H````=7](@\00
M6UU!7,,/'T0``$B)Q^APU___2(7`==5(B>_H<]7__TB)WTF)Q.AHU?__28U\
M!`+HWMC__TB#[`A)B>B^`0```%-(Q\+_____2(G'28G$3(T-;Q```$B-#6`1
M```QP.C/V/__3(GF2(T]$A$``#'`Z'[S__]86NEQ____Z-+5__]FD$%728G_
M2(T](!```$%6055!5%532('LF($``&1(BP0E*````$B)A"2(@0``,<!(C07D
M$```3(UD)"Q(QT0D0`````!(B40D,$B-!=L/``!,B>9(B40D.$B-!680``!(
MB40D<$B-!5,0``!(B40D>$B-!:@0``!(B80D@````$B-!540``!(B80DB```
M`$B-!9(0``!(B80DD````$B-!6H0``!(B40D4$B-!7L0``!(B40D6#'`2,>$
M))@`````````2,=$)&``````Z$#Q__](A<!T"8`X``^%F@0``#'`Z`O^__](
MB<-(A<`/A`\$``!(B=_H%]3__TB-?``!Z(W7__^`.P!)B<5T-TR)[4R--1X0
M```/'P!$#[8#2(GO,<!,B?%(Q\+_____O@$```!(@\,!2(/%`NASU___@#L`
M==9(C5PD<$B-/78/``#K$$B#PPA(BSM(A?\/A'`!``!,B>8QP.BF\/__2(G%
M2(7`=-Z`.`!TV4B)Q^C1]?__A<!TS4B)[^C5T___28G&2(7`#X0Y`0``9@\?
MA```````3(GWZ&C3__],B>F+,4B#P02-EO_^_O[WUB'R@>*`@("`=.B)UL'N
M$/?"@(````]$UDB-<0)(#T3.B=9``-9(@]D#3"GIC9P(!`0``$ACVTB)W^B9
MUO__055-B?"^`0```$B)Q4B-!38/``!,C0TR#@``2,?"_____U!(C0T7#P``
M2(GO,<#HA=;__[[``0``2(GOZ!C3__]!6$%9@_C_=1+H^M+__T2+"$&#^1$/
MA?8"``!,C:PDH````$B)[K\#````3(GJZ!74__]!B<:%P`^$N@```$B+!6-8
M(`!)BP])B>@QVTB-%9P/``"^`0```$B+.#'`Z.75__](BXPDB($``&1(,PPE
M*````$B)V`^%-@@``$B!Q)B!``!;74%<05U!7D%?PV8/'X0``````#'M9@\?
M1```2&/%2(M<Q#!(A=MT.X`[`'0V2(G?@\4!Z%OT__^%P'3?2(G?Z%_2__])
MB<9(A<`/A9/^__](8\5(BUS$,$B%VW7+9@\?1```13'VZ7C^__\/'X0`````
M``^WA"2P````9B4`\&8]`$`/A3#___^+A"2X````B00DZ!O4__\Y!"0/A1C_
M__\/MX0DL````&8E_P%F/<`!#X4"____2(G?Z!35__],B>9(C3V"#0``2(G#
M,<#H@.[__TB%P`^$'P(``$B)Q^B_T?__28L_2(G&Z+3U__])B<1(A<`/A``"
M``!,B>?H4-'__X/X`WX[2&/0N04```!(C3UR#0``28UT%/SSI@^7PH#:`(32
M=1N#^`0/A*H%``"#Z`1(F$&`?`3_+P^$F04``)`QP.AI^O__A<!U%3'V3(GG
MZ!O1__^)!"2%P`^%H`$``$B--=0,``!(C3U5#```,<#H.^___TR-)4@-``!,
MC2T!#```Z`C4__]!5$F)Z+X!````4$C'PO____](B=\QP$R-#=X+``!(C0WR
M#```Z#[4__]86NM-9BX/'X0``````.B[T/__@S@1=4OHP=/__T&#Q@%(@^P(
M38GI051)B>A(C0W'#```2(G?059(Q\+_____O@$```!0,<#H\=/__TB#Q""^
MP`$``$B)W^B`T/__@_C_=*M(B>_HP]+__TB)WDB-/44+```QP.B"[O__2(G?
MZ"KZ___IH/W__P\?1```2(T]!@P``#'MZPT/'T0``$ACQ4B+?,102(7_='M,
MB>8QP(/%`>CF[/__2(7`=.&`.`!TW$B)Q^@DT/__2(G#2(7`=,SIJ/O__TB+
M!9!5(`!)BP])B>@QVTB-%8D,``"^`0```$B+.#'`Z!+3___I*/W__P\?1```
M2(G'2(D$).B<^?__2(L$)$B)Q^C0S___2(G#Z0/]__^_#0```$B-'6X+``#H
MY]+__TF)Q>E:^___#Q^``````$V+)^GX_?__N@(```!(Q\;N____08G'B<?H
MFM+__TR-M"2``0``N@8```!$B?],B?;H8M'__X"\)(`!````=0Z`O"2!`0``
M0P^$7`0``(L\)#'2,?;H7M+__[B)J\WO2,>$)*`````!(T5G2(F$)*@```!(
M+8O.$E=(B80DL````$@%\@08*TB)A"3`````28U%.$C'A"2X````=E0R$$C'
MA"3(`````````$C'A"30`````````,>$)!@!````````2(E$)!"0BSPDN@"`
M``!,B?;HP-#__TB)P4&)P(7`#XYB`0``2(N\),@```!(8\%(BY0DT````(TT
MQT@Y_DB)M"3(````2(/2`$C!Z!U(`=!(B80DT````$ACA"08`0``A<`/A!8!
M``!!N$````!(B4PD"$R)]D$IP$0YP40/3L%(BTPD$$UC^$B-/`%,B?KHTL__
M_XN$)!@!``!(BTPD"$0!^(/X0(F$)!@!```/A5/___]!B<A,B>]%*?A-`?=$
MB40D".BMU/__1(M$)`A!@_@_#XZ(`@``08U`P(E$)!S!Z`9!B<2)1"0(28/$
M`4G!Y`9-`?R0\T$/;P_S00]O5Q!,B>])@\=`\T$/;U_@\T$/;V?P#Q&,)-@`
M```/$90DZ`````\1G"3X````#Q&D)`@!``#H/=3__TTYYW6XBT0D"$2+1"0<
MP>`&02G`2(M\)!!)8]"Y2````$R)YD2)1"0(Z+_.__]$BT0D"$2)A"08`0``
MZ8W^__\/'T0``$V)]^E(____BSPDZ+C.__](BX0DR````$2+I"3(````1(NT
M)-````!(P>@#00_,@^`_00_.C5`!2)C&A`38````@(/Z.`^.GP$``+A`````
M2&/**=!)C70-.(G"=`\QP(G!@\`!Q@0.`#G0<O-,B>_H@]/__V8/[\`/$80D
MV````$G'16@`````00\114A!#Q%%6$R)[T2)M"00`0``3(V\)#$!``!,C;0D
M>`$``$2)I"04`0``3(TM?@@``.@VT___BX0DH````$0/MH0DHP````_(B80D
M,`$``(N$)*@````/R(F$)#0!``"+A"2P````#\B)A"0X`0``BX0DN`````_(
MB80D/`$``(N$),`````/R(F$)$`!``!(C80D4`$``$B)!"1)B<3K#`\?0`!%
M#[8'28/'`4R)YT4/ML!,B>F^`0```$C'PO____\QP$F#Q`+H7\___TTYYG72
M2(T%)P@``,:$)'@!````4/]T)`A(C0W?!P``28GH2(G?,<"^`0```$R-#;\&
M``!(Q\+_____Z!_/__]97ND]^___38M_"$V%_P^$6_K__TR)_^ACR___2(/X
M`P^&2?K__TF-=`?\N04```!(C3V#!P``\Z8/E\`<`(3`30]$Y^DF^O__38G\
MZ>7]__^X.````#'_*=!(8]))C505.(/X"',HJ`0/A=@```"%P`^$@_[__\8"
M`*@"#X1X_O__,?]FB7P"_NEL_O__D(G!2,<"`````$C'1`KX`````$B-2@A(
M@^'X2"G*`="#X/B#^`@/@D#^__^#X/@QTHG6@\((2(D\,3G"<O/I*?[__X"\
M)((!``!!#X66^___@+PD@P$``$,/A8C[__^`O"2$`0``2`^%>OO__X"\)(4!
M``!%#X5L^___1(L\)+H"````2,?&QO___T2)_^B^S?__NBD```!,B?9$B?_H
MCLS__TB-!;L&``!005;IF?[__P\?@`````#'`@````#'1`+\`````.F@_?__
MZ.#*__]!5T%6055!5%532(/L*$B++:-/(`!D2(L$)2@```!(B40D&#'`BWT`
MZ$/+__^+?0!(B</H.,O__P^VD[@```!(C3TQ!0``B)"Y````2(U$)!1(B40D
M"$B)QC'`Z,#F__](A<!T"8`X,0^$X@(``#'`Z!OQ__^+?0#H\\K__[D+````
MN@$```!(C34`!@``2(G'Z`K+__](A<`/A+D```!(BT`0@SVF4R```42+?0!,
MBV@H#XZD````,=OK-P\?0`!)BW802(L-?5,@`$ECU$B+/-'H2<O__XL5<U,@
M`(7`#X7U`0``@\,".=-$B>,/C><!``!$B?]$C6,!Z''*__\QR4ACTTR)[DB)
MQ^@!S/__2(7`#X2X`0``3(LP1(M]`$&+1@PE``0@`#T`!```=)%$B?_H.<K_
M_TR)]KD"````,=)(B<?HU\G__T2+?0!(B<;I;____P\?`$2+?0!$B?_H#,K_
M_[D#````N@$```!(C34>!0``2(G'Z"/*__](B<-(A<!T,DB+0!"+?0!,BR#H
MW,G__TB-%?H$``!(B<=,B>;H:LG__TB+0Q!(BQCV0PY`#X72`0``BWT`Z+')
M__^Y`P```+H!````2(TUR@0``$B)Q^C(R?__2(G#2(7`=#Q(BW0D"$B-/5D#
M```QP.@MY?__28G$2(7`#X1A`0``2(M#$(M]`$B+&.ABR?__3(GB2(G>2(G'
MZ/3(__^+?0#H3,G__[H!````2(TU;`0``$B)Q^@(RO__BWT`2(G#Z"W)__](
MB=Y(C15D!```2(G'Z+O(__^+?0#H$\G__TB+="0(2(T]TP(``,:`N0`````Q
MP.BIY/__2(G#2(D%UU$@`$B%P`^$E@```+[``0``2(G?Z,G'__^-4`&#^@%V
M"8/X$0^%_@```$B+1"089$@S!"4H````#X7E````2(/$*%M=05Q!74%>05_#
M#Q]$``"+%7I1(`!$BWT`C4+_.=@/A7?^__^#^@$/CF[^__^[`0````\?1```
M1(G_@\,!Z&W(__],B>Y(B<?H@L?__SD=/%$@`$2+?0!_WND]_O__D$B+/2%1
M(`#HY/'__TB)PTB)!2)1(`!(A<`/A4O___](C3U*!```,<#H`\G__P\?`(!X
M`0`/A!O]___I#_W__Y!(BP7A4"``BWT`3(L@2(M#$$B+&.CWQ___3(GF2(G?
MZ&SI___ID_[__XM]`.C?Q___2(G>2(G'Z"3)___I%O[__^@ZQ___B<%(BP69
M4"``2(G:2(T]_P,``$B+,#'`Z(W(__]F9BX/'X0``````&:054B)_5-(@^P(
MZ-+L__\/MA!(B<.$TG0:#Q^$``````!(@\`!@/HO#[802`]$V(32=>XQP.AW
M[___2(7M="2%P'0@@'T``'0:N00```!(C3TM`@``2(G>\Z8/E\`<`(3`=`=(
M@\0(6UW#2(/$"$B)[UM=Z9GF__]F#Q^$``````!(C06Q2R``2(7`=`Q(BPCI
M[,;__P\?0``QR>GAQO__D$%7059!B?]!54%43(TEWD8@`%5(C2W>1B``4TF)
M]DF)U4PIY4B#[`A(P?T#Z#_%__](A>UT(#';#Q^$``````!,B>I,B?9$B?]!
M_Q3<2(/#`4@YW77J2(/$"%M=05Q!74%>05_#D&8N#Q^$``````#SPP``2(/L
M"$B#Q`C#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``N`%!!4E]4
M14U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]0
M5`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,
M3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%5315(`
M4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E
M<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`T-P`M90`M+0````!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(```````````<&5R;'AS:2YC`````````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I
M;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R
M7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@
M)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+
M(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@
M7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP
M<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB
M.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^
M9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*
M<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*
M?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&
M2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q
M,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@
M:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@
M9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N
M<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F
M86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O
M9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S
M="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T
M(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I
M9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F
M<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T
M("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD
M9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M
M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N
M+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]
M*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H
M)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H
M9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD
M+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I
M.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M
M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE
M(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D
M:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E
M='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D
M=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[
M8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB
M+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N
M86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D
M92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE
M(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S
M<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O
M<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T
M82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O
M+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@
M(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@
M4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM
M;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P
M;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L
M87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R
M(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV
M*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L
M("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?
M4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U
M8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*
M)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D
M<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F
M.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M
M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"![
M"B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W
M<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M
M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE
M(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*
M;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2![
M"B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA
M7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B
M*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN
M*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL
M92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%
M*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A
M)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA
M;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A
M<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I
M;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X
M+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H
M*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE
M7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C
M86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC
M;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D
M0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H
M<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@
M=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E
M<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB
M97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;
M7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N
M86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X
M=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@
M(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D
M97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE
M;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'
M5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U
M;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@
M6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H
M('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM
M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ
M9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T
M:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I
M.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U
M;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER
M92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*
M<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA
M;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?
M9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B
M/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H
M+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D
M9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O
M7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E
M<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B
M8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@
M)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#
M3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD
M)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E
M;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM
M>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D
M9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P
M96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E
M("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT
M96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX[
M"GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI
M;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?
M,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E
M;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM0
M05)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@
M/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B
M(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT
M("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U
M8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A
M<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.
M1%]?"@```````1L#.^0````;````R(7__S`!``"8B?__6`$``*B)___P!0``
MR8O__P`!``#(C/__<`$``.BB___``0``N*/__PP"``!(I/__.`(``*BF__^$
M`@``**C__\@"``"XJ/__[`(``)BI__\P`P``V*G__T@#```HJO__9`,``#BJ
M__]X`P``2*S__]@#``!XK/__[`,``%BM__\8!```2*___SP$``#(K___6`0`
M`/BO__]X!```V+#__[@$``#(N___<`4``)B___^\!0``&,#__R`&```XP/__
M.`8``*C`__^`!@```````!0``````````7I2``%X$`$;#`<(D`$'$!0````<
M````P8K__S0``````````````!0``````````7I2``%X$`$;#`<(D`$``"0`
M```<````D(3__]`#````#A!&#AA*#PMW"(``/QH[*C,D(@`````4````1```
M`#B(__\(``````````````!,````7````%"+__\6%@```$(.$(\"2@X8C@-"
M#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#[14*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A!"P```$@```"L````(*'__\P`````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P`H````^```
M`*2A__^,`````$$.$(8"1`X8@P-$#C`">PH.&$$.$$$."$$+`$@````D`0``
M"*+__U,"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`Q\!
M"@XX00XP00XH0@X@0@X80@X00@X(0PM`````<`$``!RD__]\`0```$(.$(X"
M0@X8C0-"#B",!$$.*(8%00XP@P9'#L`!?@H.,$$.*$$.($(.&$(.$$(."$L+
M`"````"T`0``6*7__XL`````00X0@P)2#J`!`G$*#A!!#@A!"T````#8`0``
MQ*7__]\`````0@X0C@)*#AB-`T(.((P$2PXHA@5!#C"#!D<.P`@"A`H.,$$.
M*$$.($(.&$(.$$(."$,+%````!P"``!@IO__,P````!$#A!9#@@`&````#0"
M``"(IO__0@````!!#A"#`F@."````!````!0`@``O*;__P,`````````7```
M`&0"``"XIO__`@(```!"#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&2PXX@P='
M#O`)`F0*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P*6#O@)30Z`"FH.^`E!#O`)
M````$````,0"``!HJ/__*0`````````H````V`(``(2H___4`````$$.$(,"
M`E\*#@A("WT*#@A+"U@*#@A("T,.""`````$`P``.*G__^<!````00X0@P)+
M#E`#;`$*#A!!#@A'"Q@````H`P``!*O__W0`````1`X@;PH."$4+```<````
M1`,``&BK__\G`````$0.$%@*#@A$"T8."````#P```!D`P``>*O__]X`````
M0@X0C`)!#AB&`TL.((,$1`XP`DP*#B!!#AA!#A!"#@A&"VX..$D.0'0..$$.
M,`"T````I`,``!BL___P"@```$(.$(\"3`X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!T<.T(,"`]X!#MB#`F$.X(,"8`[8@P)"#M"#`@*`"@XX00XP00XH0@X@
M0@X80@X00@X(2@L#>@$.V(,"20[@@P)@#MB#`D$.T(,"8P[8@P)%#N"#`D\.
MZ(,"30[P@P)+#M"#`@.C!`[8@P)$#N"#`F@.V(,"00[0@P(#-P$*#MB#`D(.
MX(,"3`L`2````%P$``!0MO__PP,```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=$#F`#L@(*#CA!#C!!#BA"#B!"#AA"#A!"#@A&"S````"H!```
MU+G__W<`````00X0A@)$#AB#`T0.(`)="@X800X000X(00M$#AA$#A!!#@@L
M````W`0``+"#__\A`@```$$.$(8"00X8@P-$#E`#B0$*#AA!#A!!#@A!"P``
M```4````#`4``/"Y__\?``````````````!$````)`4``/BY__]E`````$(.
M$(\"0@X8C@-%#B"-!$(.*(P%2`XPA@9(#CB#!TT.0'(..$$.,$$.*$(.($(.
M&$(.$$(."``0````;`4``""Z__\"````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#P(```
M`````+`@`````````0`````````!``````````$`````````P0$````````!
M`````````,P!`````````0````````#6`0````````$`````````)0(`````
M```!`````````'4#````````#`````````#@&0````````T`````````Y%0`
M```````9`````````&";(```````&P`````````(`````````!H`````````
M:)L@```````<``````````@`````````]?[_;P````"@`@````````4`````
M````R`P````````&`````````(`#````````"@````````#)!`````````L`
M````````&``````````5`````````````````````P````````"PG2``````
M``(`````````H`4````````4``````````<`````````%P````````!`%```
M``````<`````````V!(````````(`````````&@!````````"0`````````8
M`````````!X`````````"`````````#[__]O``````$```@`````_O__;P``
M``!8$@```````/___V\``````@````````#P__]O`````)(1````````^?__
M;P`````$````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````<)L@````````````````````````````%AH````````F&@```````#8:
M````````1AH```````!6&@```````&8:````````=AH```````"&&@``````
M`)8:````````IAH```````"V&@```````,8:````````UAH```````#F&@``
M`````/8:````````!AL````````6&P```````"8;````````-AL```````!&
M&P```````%8;````````9AL```````!V&P```````(8;````````EAL`````
M``"F&P```````+8;````````QAL```````#6&P```````.8;````````]AL`
M```````&'````````!8<````````)AP````````V'````````$8<````````
M5AP```````!F'````````'8<````````AAP```````"6'````````*8<````
M````MAP```````#&'````````-8<````````YAP```````#V'`````````8=
M````````%AT````````F'0```````#8=````````1AT```````!6'0``````
M`&8=````````=AT```````"&'0```````)8=````````IAT```````"V'0``
M`````,8=````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"*`@``````#_____``````!8````````1T-#
M.B`H1&5B:6%N(#@N,BXP+3@I(#@N,BXP`$=#0SH@*$1E8FEA;B`V+C0N,"TW
M*2`V+C0N,"`R,#$W,#DR,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))
M+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR
M96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y
M`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M````````````````````````````````````````````````````````````
M```````+`````0````(`````````.`(````````X`@```````!T`````````
M```````````!````````````````````$P````<````"`````````%@"````
M````6`(````````@````````````````````!````````````````````"$`
M```'`````@````````!X`@```````'@"````````)```````````````````
M``0````````````````````T````]O__;P(`````````H`(```````"@`@``
M`````-P`````````!0`````````(````````````````````/@````L````"
M`````````(`#````````@`,```````!("0````````8````!````"```````
M```8`````````$8````#`````@````````#(#````````,@,````````R00`
M``````````````````$```````````````````!.````____;P(`````````
MDA$```````"2$0```````,8`````````!0`````````"``````````(`````
M````6P```/[__V\"`````````%@2````````6!(```````"```````````8`
M```"````"````````````````````&H````$`````@````````#8$@``````
M`-@2````````:`$````````%``````````@`````````&`````````!T````
M!````$(`````````0!0```````!`%````````*`%````````!0```!8````(
M`````````!@`````````?@````$````&`````````.`9````````X!D`````
M```7````````````````````!````````````````````'D````!````!@``
M````````&@`````````:````````T`,``````````````````!``````````
M$`````````"$`````0````8`````````T!T```````#0'0````````@`````
M```````````````(``````````@`````````C0````$````&`````````.`=
M````````X!T````````"-P``````````````````$```````````````````
M`),````!````!@````````#D5````````.14````````"0``````````````
M``````0```````````````````"9`````0````(`````````\%0```````#P
M5````````$@_```````````````````(````````````````````H0````$`
M```"`````````#B4````````.)0```````#D````````````````````!```
M`````````````````*\````!`````@`````````@E0```````""5````````
ML`4```````````````````@```````````````````"Y````#@````,`````
M````8)L@``````!@FP````````@````````````````````(``````````@`
M````````Q0````\````#`````````&B;(```````:)L````````(````````
M````````````"``````````(`````````-$````&`````P````````!PFR``
M`````'";````````0`(````````&``````````@`````````$`````````"(
M`````0````,`````````L)T@``````"PG0```````%`"````````````````
M```(``````````@`````````V@````$````#``````````"@(````````*``
M```````@````````````````````"````````````````````.`````(````
M`P`````````@H"```````""@````````2`0``````````````````"``````
M``````````````#E`````0```#`````````````````````@H````````$$`
M```````````````````!``````````$``````````0````,`````````````
M````````````8:````````#N`````````````````````0``````````````
$````````
